==> dl.php?src=linea21_2_3_0.zip: linea21/contents/mod.php <==
<?php
/**
 * Handle content for publication and workgroup report modules
 * 
 * Modify publication or workgroup report content from back-office
 * 
 * @package linea21\modules\content
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Content' module is used by 'Publication' and 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$complete_type=strtoupper($mod_inc);

$contents_object = new contents;


if($type=='P') {
  $requete= SQL_getOnePublicationParts($id);
  $result=$sql_object->DBSelect($requete);
  
  // Do record exists?
  if(!isset($result[0]['publicon_title'])) redirect_to('publication');
  
  $form_title=formatText($result[0]['publicon_title'],'2FIELD');
  $form_body=formatText($result[0]['publicon_body'],'2FIELD');
}
if($type=='W') {
  $requete= SQL_getOneWorkshopParts($id);
  $result=$sql_object->DBSelect($requete);
  
  // Do record exists?
  if(!isset($result[0]['workrepcon_title'])) redirect_to('workshop');
  
  $form_title=formatText($result[0]['workrepcon_title'], '2FIELD');
  $form_body=formatText($result[0]['workrepcon_body'], '2FIELD');
}



if(isset($_POST['enregistrer'])) {

  $data_table=unserialize(urldecode($_POST['data_table']));
  $result=$contents_object->ModifyContents($id, $data_table, $complete_type, $sql_object);

  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&type=".$type."&id=".$parent;
  if($result) header("Location: ".safe_redirect($link_confirm));
  else  system_error();
}

if(isset($_POST['valider'])) {
    
  $table = array();
  $table[0]=$_POST['part_title'];
  $table[1]=$_POST['part_body'];

  $integrity=$contents_object->CheckDataIntegrity($table,$type);


  if(is_string($integrity)) {
    $text_format='2FIELD';
  } else {
    $text_format='2HTML';
  }

  $form_title=formatText($_POST['part_title'], $text_format);
  $form_body=formatText($_POST['part_body'], $text_format);

  $table=urlencode(serialize($table));
}

if($type=='P') {
  $requete= SQL_getPublicationTitle($parent);
  $result=$sql_object->DBSelect($requete);
  
  // Do record exists?
  if(!isset($result[0]['publi_title'])) redirect_to('publication');
  
  $current_title=FormatText($result[0]['publi_title'], '2HTML');
  $current_owner=$result[0]['publi_posted_by'];

  //////////// Check Droits utilisateur ////////////
  if ($l21auth->GetSessionElement('id')!=$current_owner && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
  ///////////

}
if($type=='W') {
  $requete= SQL_getWorkshopRepTitleAndGroup($parent);
  $result=$sql_object->DBSelect($requete);
  
  // Do record exists?
  if(!isset($result[0]['workrep_title'])) redirect_to('workshop');
  
  $current_title=FormatText($result[0]['workrep_title'], '2HTML');
  $current_workshop_id=$result[0]['workrep_workshop_id'];
  $current_workshop_name = FormatText($result[0]['workshop_denomination']);

  //////////// Check Droits utilisateur ////////////
  if (!$l21auth->isWorkgroupOrganiser($l21auth->GetSessionElement('id'), $sql_object, $current_workshop_id) && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
  ///////////

}
?>
<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu',$mod_inc); ?></a></li>
	<li><span><?php echo formatNavTitle(_t('contents',$mod_inc.'_type')." : ". $current_title); ?></span></li>
</ul>
</div>
<!--end barre haute -->

<?php
if(!isset($integrity) || is_string($integrity)) {
  ?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">

<?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>

<h2><?php echo formatTitleh2($current_title); ?></h2>
<?php 
if($type=='W') echo '<div class="subtitle" id="workshop-subtitle">'.$current_workshop_name.'</div>';
?>
<form id="modpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
  <p>
    <label for="part_title"><?php echo mb_ucfirst(_t('contents','title')); ?> : *</label>
    <input name="part_title" type="text" class="textfield" id="part_title" maxlength="200" value="<?php echo $form_title; ?>" required />
  </p>
  <p>
    <label for="part_body"><?php echo mb_ucfirst(_t('contents','body')); ?> : *</label>
    <textarea id="part_body" name="part_body" class="largetextfield" <?php echo AREA_SETTINGS; ?> required><?php echo $form_body; ?></textarea>
  </p>

  <div>
    <input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
    <input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
    <input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
    <input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
    <input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
    <?php echo cancel_button($cancel_link); ?>
    <input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
  </div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
<?php
// Récapitulatif
} else	{
?>
<div class="contentcontainer">
<?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
  <div id="content">
  <h2><?php echo formatTitleh2(_t('recap','title')); ?></h2>
  <?php
  echo "<dl class=\"summary\">\n";
  echo "<dt>".mb_ucfirst(_t('contents','title'))." :</dt>\n";
  echo "<dd>".$form_title."</dd>\n";
  echo "<dt>".mb_ucfirst(_t('contents','body'))." :</dt>\n";
  echo "<dd>".$form_body."</dd>\n";
  echo "</dl>\n";
  ?>
  <form id="modpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
    <div>
      <input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
      <input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
      <input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
      <input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
      <input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
      <input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
      <?php echo cancel_button($cancel_link); ?>
      <input name="retour" type="button" value="<?php echo _t('btn','preview') ?>" class="button" id="retour" onclick="history.go(-1);" />
      <input name="enregistrer" type="submit" value="<?php echo _t('btn','save') ?>" class="button" id="valider" />
    </div>
  </form>
	</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
<?php
}
?>

==> dl.php?src=linea21_2_5_0.zip: linea21/contents/mod.php <==
<?php
/**
 * Handle content for publication and workgroup report modules
 * 
 * Modify publication or workgroup report content from back-office
 * 
 * @package linea21\modules\content
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Content' module is used by 'Publication' and 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$complete_type=strtoupper($mod_inc);

$contents_object = new contents;


if($type=='P') {
  $requete= SQL_getOnePublicationParts($id);
  $result=$sql_object->DBSelect($requete);
  
  // Do record exists?
  if(!isset($result[0]['publicon_title'])) redirect_to('publication');
  
  $form_title=formatText($result[0]['publicon_title'],'2FIELD');
  $form_body=formatText($result[0]['publicon_body'],'2FIELD');
}
if($type=='W') {
  $requete= SQL_getOneWorkshopParts($id);
  $result=$sql_object->DBSelect($requete);
  
  // Do record exists?
  if(!isset($result[0]['workrepcon_title'])) redirect_to('workshop');
  
  $form_title=formatText($result[0]['workrepcon_title'], '2FIELD');
  $form_body=formatText($result[0]['workrepcon_body'], '2FIELD');
}



if(isset($_POST['enregistrer'])) {

  $data_table=unserialize(urldecode($_POST['data_table']));
  $result=$contents_object->ModifyContents($id, $data_table, $complete_type, $sql_object);

  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&type=".$type."&id=".$parent;
  if($result) {
      header("Location: ".safe_redirect($link_confirm));
      exit;
  }
  else  system_error();
}

if(isset($_POST['valider'])) {
    
  $table = array();
  $table[0]=$_POST['part_title'];
  $table[1]=$_POST['part_body'];

  $integrity=$contents_object->CheckDataIntegrity($table,$type);


  if(is_string($integrity)) {
    $text_format='2FIELD';
  } else {
    $text_format='2HTML';
  }

  $form_title=formatText($_POST['part_title'], $text_format);
  $form_body=formatText($_POST['part_body'], $text_format);

  $table=urlencode(serialize($table));
}

if($type=='P') {
  $requete= SQL_getPublicationTitle($parent);
  $result=$sql_object->DBSelect($requete);
  
  // Do record exists?
  if(!isset($result[0]['publi_title'])) redirect_to('publication');
  
  $current_title=FormatText($result[0]['publi_title'], '2HTML');
  $current_owner=$result[0]['publi_posted_by'];

  //////////// Check Droits utilisateur ////////////
  if ($l21auth->GetSessionElement('id')!=$current_owner && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
  ///////////

}
if($type=='W') {
  $requete= SQL_getWorkshopRepTitleAndGroup($parent);
  $result=$sql_object->DBSelect($requete);
  
  // Do record exists?
  if(!isset($result[0]['workrep_title'])) redirect_to('workshop');
  
  $current_title=FormatText($result[0]['workrep_title'], '2HTML');
  $current_workshop_id=$result[0]['workrep_workshop_id'];
  $current_workshop_name = FormatText($result[0]['workshop_denomination']);

  //////////// Check Droits utilisateur ////////////
  if (!$l21auth->isWorkgroupOrganiser($l21auth->GetSessionElement('id'), $sql_object, $current_workshop_id) && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
  ///////////

}
?>
<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu',$mod_inc); ?></a></li>
	<li><span><?php echo formatNavTitle(_t('contents',$mod_inc.'_type')." : ". $current_title); ?></span></li>
</ul>
</div>
<!--end barre haute -->

<?php
if(!isset($integrity) || is_string($integrity)) {
  ?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">

<?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>

<h2><?php echo formatTitleh2($current_title); ?></h2>
<?php 
if($type=='W') echo '<div class="subtitle" id="workshop-subtitle">'.$current_workshop_name.'</div>';
?>
<form id="modpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
  <p>
    <label for="part_title"><?php echo mb_ucfirst(_t('contents','title')); ?> : *</label>
    <input name="part_title" type="text" class="textfield" id="part_title" maxlength="200" value="<?php echo $form_title; ?>" required />
  </p>
  <p>
    <label for="part_body"><?php echo mb_ucfirst(_t('contents','body')); ?> : *</label>
    <textarea id="part_body" name="part_body" class="largetextfield" <?php echo AREA_SETTINGS; ?> required><?php echo $form_body; ?></textarea>
  </p>

  <div>
    <input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
    <input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
    <input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
    <input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
    <input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
    <?php echo cancel_button($cancel_link); ?>
    <input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
  </div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
<?php
// Récapitulatif
} else	{
?>
<div class="contentcontainer">
<?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
  <div id="content">
  <h2><?php echo formatTitleh2(_t('recap','title')); ?></h2>
  <?php
  echo "<dl class=\"summary\">\n";
  echo "<dt>".mb_ucfirst(_t('contents','title'))." :</dt>\n";
  echo "<dd>".$form_title."</dd>\n";
  echo "<dt>".mb_ucfirst(_t('contents','body'))." :</dt>\n";
  echo "<dd>".$form_body."</dd>\n";
  echo "</dl>\n";
  ?>
  <form id="modpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
    <div>
      <input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
      <input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
      <input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
      <input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
      <input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
      <input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
      <?php echo cancel_button($cancel_link); ?>
      <input name="retour" type="button" value="<?php echo _t('btn','preview') ?>" class="button" id="retour" onclick="history.go(-1);" />
      <input name="enregistrer" type="submit" value="<?php echo _t('btn','save') ?>" class="button" id="valider" />
    </div>
  </form>
	</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
<?php
}
?>
